parse_rcsb_id: Parse an RCSB Identifier

View source: R/id_helpers.R

parse_rcsb_idR Documentation

Parse an RCSB Identifier

Description

Parses an identifier into a structured record when possible.

Usage

parse_rcsb_id(id)

Arguments

id

A scalar identifier.

Value

A named list with parsed fields and inferred type.


rPDBapi documentation built on Aug. 21, 2026, 9:16 a.m.