| infer_id_type | R Documentation |
Infers the likely identifier category for one or more RCSB-related IDs. This helper is additive and does not affect existing workflows unless called explicitly.
infer_id_type(id)
id |
A character vector of identifiers. |
A character vector with inferred types: "ENTRY",
"ASSEMBLY", "ENTITY", "INSTANCE",
"CHEMICAL_COMPONENT", or "UNKNOWN".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.