Learn R Programming

rPDBapi (version 3.0.0)

infer_id_type: Infer RCSB Identifier Type

Description

Infers the likely identifier category for one or more RCSB-related IDs. This helper is additive and does not affect existing workflows unless called explicitly.

Usage

infer_id_type(id)

Value

A character vector with inferred types: "ENTRY",

"ASSEMBLY", "ENTITY", "INSTANCE",

"CHEMICAL_COMPONENT", or "UNKNOWN".

Arguments

id

A character vector of identifiers.