powered by
Infers the likely identifier category for one or more RCSB-related IDs. This helper is additive and does not affect existing workflows unless called explicitly.
infer_id_type(id)
A character vector with inferred types: "ENTRY",
"ENTRY"
"ASSEMBLY", "ENTITY", "INSTANCE",
"ASSEMBLY"
"ENTITY"
"INSTANCE"
"CHEMICAL_COMPONENT", or "UNKNOWN".
"CHEMICAL_COMPONENT"
"UNKNOWN"
A character vector of identifiers.