| parse_rcsb_id | R Documentation |
Parses an identifier into a structured record when possible.
parse_rcsb_id(id)
id |
A scalar identifier. |
A named list with parsed fields and inferred type.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.